@@ -140,7 +140,7 @@ DVBase[VITD] = 400;
 DVBase[LA] = 6;
 DVBase[AA] = 0.2;
 DVBase[OMEGA6] = DVBase[LA] + DVBase[AA];
-DVBase[ALA] = 2;
+DVBase[ALA] = 2.89;
 DVBase[EPA] = 0.33;
 DVBase[DHA] = 0.33;
 DVBase[OMEGA3] = DVBase[ALA] + DVBase[EPA] + DVBase[DHA];
