@@ -514,7 +514,7 @@ else DV[CHO_NONFIB] = options.abnuts[CHO_NONFIB];
 temp = 1 - (DV[PROCNT] * options.protcalpergm + DV[CHOCDF] * options.carbcalpergm) / DV[ENERC_KCAL];
 if (temp > .32 && options.pcsatfat <= 0 && options.abnuts[FASAT] <= 0 && options.abnuts[FAMS] <= 0) 
  {
- temp = (DV[FASAT] * temp / .3) - DV[FASAT];
+ temp = (1.04 * DV[FASAT] * temp / .3) - DV[FASAT];
  DV[FASAT] += temp;
  DV[FAMS] -= temp;
  if (analflag && food_work.nutrient[FASAT] < DV[FASAT])
@@ -693,10 +693,10 @@ options.defanal = count - count % options.mealsperday;
 void efa_dynamics()
 {
 int i;
-float temp, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
-float target = 61, epadhalimit, extra_ala;
+float temp, temp1, temp_la = 0, temp_aa = 0, hufapct, p3, h3, h6, p6, o;
+float target = 62, epadhalimit, extra_ala;
 
-epadhalimit = DV[ENERC_KCAL] * .0077 / 9.02;
+epadhalimit = DV[ENERC_KCAL] * .0069 / 9.02;
 
 if (options.n6hufa != 0)
  {
@@ -731,8 +731,9 @@ if (food_work.nutrient[EPA] > .02 || food_work.nutrient[DHA] > .02 || food_work.
  if (options.abnuts[EPA] + options.abnuts[DHA] > epadhalimit)
   {
   temp = options.abnuts[EPA] + options.abnuts[DHA] - epadhalimit;
-  options.abnuts[EPA] -= options.abnuts[EPA] / (options.abnuts[EPA] + options.abnuts[DHA]) * temp;
-  options.abnuts[DHA] -= options.abnuts[DHA] / (options.abnuts[EPA] + options.abnuts[DHA]) * temp;
+  temp1 = options.abnuts[EPA] / (options.abnuts[EPA] + options.abnuts[DHA]);
+  options.abnuts[EPA] -= temp * temp1;
+  options.abnuts[DHA] -= temp * (1 - temp1);
   options.abnuts[OMEGA3] -= temp;
   h3 -= 902 * temp / food_work.nutrient[ENERC_KCAL];
   for (i = 1; i < 200000; i++)
